@@ -10,7 +10,7 @@ rvg = Magick::RVG.new(400, 150) do |canvas|
         grp.line(1.5, 0, 1.5, 150)
     end
 
-    canvas.text(30, 30, 'ABC (orig coord system)').styles(:font_size=>20, :font_family=>'Verdana')
+    canvas.text(30, 30, 'ABC (orig coord system)').styles(:font_size=>20, :font_family=>'Verdana', :font_weight=>'normal', :font_style=>'normal')
 
 end
 
