@@ -101,20 +101,20 @@ SmileBits = [
     0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
     0, 0, 0, 0 ]
 
-	img = Image.new(SmileWidth, SmileHeight)
-    
+  img = Image.new(SmileWidth, SmileHeight)
+
     q = Array.new                           # Create an array of pixels one
     SmileWidth.times do                     # row long
         q << Magick::Pixel.new(0,0,0,0)
     end
 
-	n = 0
+  n = 0
     SmileHeight.times do |y|                # Store pixels a row at a time
         SmileWidth.times do |x|             # Build a row of pixels
-            q[x].red   = MaxRGB * SmileBits[n]
-            q[x].green = MaxRGB * SmileBits[n]
-            q[x].blue  = MaxRGB * SmileBits[n]
-			n += 1
+            q[x].red   = QuantumRange * SmileBits[n]
+            q[x].green = QuantumRange * SmileBits[n]
+            q[x].blue  = QuantumRange * SmileBits[n]
+      n += 1
         end
                                             # Store the row of pixels
         img.store_pixels(0, y, SmileWidth, 1, q)
